@@ -77,21 +77,21 @@ openapi_schema = {
 
 def test_openapi_schema():
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == openapi_schema
 
 
 def test_post_body():
     data = {"2": 2.2, "3": 3.3}
     response = client.post("/index-weights/", json=data)
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == data
 
 
 def test_post_invalid_body():
     data = {"foo": 2.2, "3": 3.3}
     response = client.post("/index-weights/", json=data)
-    assert response.status_code == 422
+    assert response.status_code == 422, response.text
     assert response.json() == {
         "detail": [
             {
